@@ -41,7 +41,7 @@ use Pod::Usage;
 
 use InSilicoSpectro::InSilico::ModRes;
 use InSilicoSpectro::InSilico::CleavEnzyme;
-use Phenyx::InSilicoSpectro;
+use InSilicoSpectro;
 
 my ($help, $verbose, $dest, $username);
 if (!GetOptions('dest=s'=> \$dest,
@@ -52,7 +52,7 @@ if (!GetOptions('dest=s'=> \$dest,
 }
 
 # Opens and parse
-my $src = $ARGV[0] || die "must provide a resid_xml source (url or file)";
+my $src = $ARGV[0] || CORE::die "must provide a resid_xml source (url or file)";
 
 my $residFile;
 if($src=~/^(ftp|http):/i){
@@ -79,12 +79,12 @@ my $parser = new XML::Parser(Style => 'Stream');
 if($src eq '-'){
   $parser->parse(\*STDIN);
 }else{
-  open(F, $residFile) || die ("cannot open [$residFile]: $!");
+  open(F, $residFile) || CORE::die ("cannot open [$residFile]: $!");
   $parser->parse(\*F);
   close(F);
 }
 
-Phenyx::InSilicoSpectro::saveInSilicoDef($dest);
+InSilicoSpectro::saveInSilicoDef($dest);
 
 # ------------------------------ XML --------------------------
 
